# PUNPPCI: Penalising Unexplainability Network Payments per Claim Incurred

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)

A package for processing insurance premiums and claims data, with scikit-learn compatible applications of the PUNPPCI risk pricing and reserving model, as well as chain ladder and PPCI.

## Installation:

```{sh}
pip install punppci
```

## Usage:

Refer to [Example.ipynb](https://github.com/JackyP/penalised-unexplainability-network-payments-per-claim-incurred/blob/master/Example.ipynb) for an example.
